summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/player.cc
diff options
context:
space:
mode:
authorDavid Ploog <dploog@users.sourceforge.net>2009-10-23 08:54:42 +0200
committerDavid Ploog <dploog@users.sourceforge.net>2009-10-23 08:54:42 +0200
commit4b41d9b5d515c32cd872e73fa91aaa702cc016c9 (patch)
tree8e1b915a1ea7499924029e4b9d9f22d4cd5032c7 /crawl-ref/source/player.cc
parentc51e405ca1d1c20253ce33a9cd480e23dee67d3a (diff)
downloadcrawl-ref-4b41d9b5d515c32cd872e73fa91aaa702cc016c9.tar.gz
crawl-ref-4b41d9b5d515c32cd872e73fa91aaa702cc016c9.zip
Rename Chronos to Cheibriados. (Jude Brown)
Diffstat (limited to 'crawl-ref/source/player.cc')
-rw-r--r--crawl-ref/source/player.cc12
1 files changed, 6 insertions, 6 deletions
diff --git a/crawl-ref/source/player.cc b/crawl-ref/source/player.cc
index a63077e149..1796bf9444 100644
--- a/crawl-ref/source/player.cc
+++ b/crawl-ref/source/player.cc
@@ -1196,9 +1196,9 @@ int player_hunger_rate(void)
if (you.duration[DUR_REGENERATION])
hunger += 4;
// If Chronos has slowed your life processes, there's a
// chance you'll hunger a bit less.
- if (GOD_CHRONOS == you.religion
+ if (GOD_CHEIBRIADOS == you.religion
&& piety_rank(you.piety) >= 1
&& coinflip())
hunger--;
@@ -5448,10 +5448,10 @@ bool poison_player(int amount, bool force)
void dec_poison_player()
{
// If Chronos has slowed your life processes, there's a
// chance that your poison level is simply unaffected and
// you aren't hurt by poison.
- if (GOD_CHRONOS == you.religion
+ if (GOD_CHEIBRIADOS == you.religion
&& piety_rank(you.piety) >= 1
&& coinflip())
return;
@@ -5720,9 +5720,9 @@ void dec_disease_player()
{
if (you.disease > 0)
{
// If Chronos has slowed your life processes, there's a
// chance that your disease level is unaffected.
- if (GOD_CHRONOS == you.religion
+ if (GOD_CHEIBRIADOS == you.religion
&& piety_rank(you.piety) >= 1
&& coinflip())
{
@@ -1196,9 +1196,9 @@ int player_hunger_rate(void)
if (you.duration[DUR_REGENERATION])
hunger += 4;
- // If Chronos has slowed your life processes, there's a
+ // If Cheibriados has slowed your life processes, there's a
// chance you'll hunger a bit less.
@@ -5448,10 +5448,10 @@ bool poison_player(int amount, bool force)
void dec_poison_player()
{
- // If Chronos has slowed your life processes, there's a
+ // If Cheibriados has slowed your life processes, there's a
// chance that your poison level is simply unaffected and
// you aren't hurt by poison.
@@ -5720,9 +5720,9 @@ void dec_disease_player()
if (you.disease > 0)
{
- // If Chronos has slowed your life processes, there's a
+ // If Cheibriados has slowed your life processes, there's a
// chance that your disease level is unaffected.